==> smartgwt-4.0p.zip: com/smartgwt/client/docs/Databinding.java <==

package com.smartgwt.client.docs;

/**
 * <h3>DataBinding</h3>
 * DataBinding means the automatic, highly customizable process of 'binding' a UI component to a
 * DataSource, so that a UI component displays, edits and saves DataSource records using
 * appropriate formatters, editors, validation rules, and persistence logic.
 * @see com.smartgwt.client.widgets.tree.ResultTree#getDataSource
 * @see com.smartgwt.client.widgets.calendar.Calendar#getAutoFetchData
 * @see com.smartgwt.client.widgets.calendar.Calendar#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.calendar.Calendar#getShowDetailFields
 * @see com.smartgwt.client.widgets.calendar.Calendar#getDataFetchMode
 * @see com.smartgwt.client.widgets.form.DynamicForm#getDataFetchMode
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getShowOptionsFromDataSource
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getShowOptionsFromDataSource
 * @see com.smartgwt.client.widgets.viewer.DetailViewer#getDataFetchMode
 * @see com.smartgwt.client.widgets.viewer.DetailViewer#getShowDetailFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDataSource
 * @see com.smartgwt.client.widgets.grid.ListGrid#getSaveLocally
 * @see com.smartgwt.client.widgets.grid.ListGrid#getUseRemoteValidators
 * @see com.smartgwt.client.widgets.grid.ListGrid#getUseAllDataSourceFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getShowDetailFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDataProperties
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDataFetchMode
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCanRemoveRecords
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getDataSource
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getLoadDataOnDemand
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getTreeRootValue
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getFields
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getUseAllDataSourceFields
 * @see com.smartgwt.client.widgets.tile.TileGrid#getDataSource
 * @see com.smartgwt.client.widgets.tile.TileGrid#getAutoFetchData
 * @see com.smartgwt.client.widgets.tile.TileGrid#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.tile.TileGrid#getDataFetchMode
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getDataSource
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getAutoFetchData
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getShowDetailFields
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getDataFetchMode
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getLoadDataOnDemand
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getAutoFetchData
 * @see com.smartgwt.client.widgets.form.DynamicForm#getAutoFetchData
 * @see com.smartgwt.client.widgets.form.DynamicForm#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.cube.CubeGrid#getAutoFetchData
 */
public interface Databinding {
}

==> smartgwt-5.0p.zip: com/smartgwt/client/docs/Databinding.java <==

package com.smartgwt.client.docs;

/**
 * <h3>DataBinding</h3>
 * DataBinding means the automatic, highly customizable process of 'binding' a UI component to a
 * DataSource, so that a UI component displays, edits and saves DataSource records using
 * appropriate formatters, editors, validation rules, and persistence logic.
 * @see com.smartgwt.client.widgets.tree.ResultTree#getDataSource
 * @see com.smartgwt.client.widgets.calendar.Calendar#getAutoFetchData
 * @see com.smartgwt.client.widgets.calendar.Calendar#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.calendar.Calendar#getShowDetailFields
 * @see com.smartgwt.client.widgets.calendar.Calendar#getDataFetchMode
 * @see com.smartgwt.client.widgets.cube.CubeGrid#getAutoFetchData
 * @see com.smartgwt.client.widgets.cube.CubeGrid#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.grid.ListGrid#getAutoFetchData
 * @see com.smartgwt.client.widgets.form.DynamicForm#getAutoFetchData
 * @see com.smartgwt.client.widgets.form.DynamicForm#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.viewer.DetailViewer#getDataFetchMode
 * @see com.smartgwt.client.widgets.viewer.DetailViewer#getShowDetailFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDataSource
 * @see com.smartgwt.client.widgets.grid.ListGrid#getSaveLocally
 * @see com.smartgwt.client.widgets.grid.ListGrid#getUseRemoteValidators
 * @see com.smartgwt.client.widgets.grid.ListGrid#getUseAllDataSourceFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getShowDetailFields
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDataProperties
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDataFetchMode
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCanRemoveRecords
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getDataSource
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getLoadDataOnDemand
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getTreeRootValue
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getFields
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getDataProperties
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getUseAllDataSourceFields
 * @see com.smartgwt.client.widgets.menu.Menu#getInitialCriteria
 * @see com.smartgwt.client.widgets.menu.Menu#getAutoFetchData
 * @see com.smartgwt.client.widgets.menu.Menu#getDataProperties
 * @see com.smartgwt.client.widgets.menu.TreeMenuButton#getDataProperties
 * @see com.smartgwt.client.widgets.tile.TileGrid#getDataSource
 * @see com.smartgwt.client.widgets.tile.TileGrid#getAutoFetchData
 * @see com.smartgwt.client.widgets.tile.TileGrid#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.tile.TileGrid#getDataFetchMode
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getDataSource
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getDataProperties
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getAutoFetchData
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getAutoFetchTextMatchStyle
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getShowDetailFields
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getDataFetchMode
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getLoadDataOnDemand
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getFields
 * @see com.smartgwt.client.widgets.form.DynamicForm#getDataFetchMode
 * @see com.smartgwt.client.widgets.form.fields.SelectItem#getShowOptionsFromDataSource
 * @see com.smartgwt.client.widgets.form.fields.ComboBoxItem#getShowOptionsFromDataSource
 * @see com.smartgwt.client.widgets.form.fields.PickTreeItem#getDataProperties
 */
public interface Databinding {
}
